@@ -4,10 +4,14 @@
 import unittest
 from datetime import datetime, timedelta
 import pytz
-from croniter import croniter, croniter_range, CroniterBadDateError, CroniterBadCronError
+from croniter import croniter, croniter_range, CroniterBadDateError, CroniterBadCronError, CroniterBadTypeRangeError
 from croniter.tests import base
 
 
+class mydatetime(datetime):
+    """."""
+
+
 class CroniterRangeTest(base.TestCase):
 
     def test_1day_step(self):
@@ -148,6 +152,28 @@ class CroniterRangeTest(base.TestCase):
             i = croniter_range(datetime(2020, 1, 1), datetime(2020, 12, 31), cron, _croniter=croniter_nosec)
             next(i)
 
+    def test_dt_types(self):
+        start = mydatetime(2020, 9, 24)
+        stop = datetime(2020, 9, 28)
+        try:
+            list(croniter_range(start, stop, '0 0 * * *'))
+        except CroniterBadTypeRangeError:
+            self.fail('should not be triggered')
+
+    def test_dst_iter(self):
+        tz = pytz.timezone('Asia/Hebron')
+        now = datetime(2022, 3, 26, 0, 0, 0, tzinfo=tz)
+        it = croniter('0 0 * * *', now)
+        ret = [
+            it.get_next(datetime).isoformat(),
+            it.get_next(datetime).isoformat(),
+            it.get_next(datetime).isoformat(),
+        ]
+        self.assertEqual(ret, [
+            '2022-03-26T00:00:00+02:00',
+            '2022-03-27T01:00:00+03:00',
+            '2022-03-28T00:00:00+03:00'])
+
 
 if __name__ == '__main__':
     unittest.main()
